@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 use Dist::Zilla;
 
@@ -236,14 +236,14 @@ sub _build_plugins {
             },
         ],
         [
-            'Prereqs' => 'TestMoreDoneTesting' => {
+            'Prereqs' => 'Test::More with subtest()' => {
                 -phase       => 'test',
                 -type        => 'requires',
-                'Test::More' => '0.88',
+                'Test::More' => '0.96',
             }
         ],
         [
-            'PromptIfStale' => 'stale modules, release' => {
+            'PromptIfStale' => {
                 phase             => 'release',
                 check_all_plugins => 1,
                 check_all_prereqs => 1,
@@ -255,12 +255,12 @@ sub _build_plugins {
             }
         ],
         [
-            'ReadmeAnyFromPod' => 'ReadmeMarkdownInBuild' => {
+            'ReadmeAnyFromPod' => 'README.md in build' => {
                 filename => 'README.md',
             },
         ],
         [
-            'ReadmeAnyFromPod' => 'ReadmeMarkdownInRoot' => {
+            'ReadmeAnyFromPod' => 'README.md in root' => {
                 filename => 'README.md',
             },
         ],
@@ -289,7 +289,7 @@ sub _build_plugins {
         [ 'Test::ReportPrereqs' => { verify_prereqs => 1 }, ],
         [ 'Test::Version'       => { is_strict      => 1 }, ],
 
-        # from @Basic
+        # mostly from @Basic
         qw(
             ManifestSkip
             MetaYAML
@@ -298,6 +298,7 @@ sub _build_plugins {
             ExecDir
             ShareDir
             Manifest
+            CheckVersionIncrement
             TestRelease
             ConfirmRelease
             UploadToCPAN
@@ -315,6 +316,7 @@ sub _build_plugins {
             Meta::Contributors
             MetaConfig
             MetaJSON
+            RewriteVersion
             SurgicalPodWeaver
             ),
         qw(
@@ -329,19 +331,27 @@ sub _build_plugins {
             Test::Synopsis
             Test::TidyAll
             ),
-        qw(
-            RewriteVersion
-            BumpVersionAfterRelease
-            CheckVersionIncrement
-            ),
 
         # from @Git - note that the order here is important!
-        [ 'Git::Check'  => { allow_dirty => \@allow_dirty }, ],
-        [ 'Git::Commit' => { allow_dirty => \@allow_dirty }, ],
+        [ 'Git::Check' => { allow_dirty => \@allow_dirty }, ],
+        [
+            'Git::Commit' => 'commit generated files' => {
+                allow_dirty => \@allow_dirty,
+            },
+        ],
         qw(
             Git::Tag
             Git::Push
             ),
+
+        'BumpVersionAfterRelease',
+        [
+            'Git::Commit' => 'commit version bump' => {
+                allow_dirty_match => ['.+'],
+                commit_msg        => 'Bump version after release'
+            },
+        ],
+        [ 'Git::Push' => 'push version bump' ],
     );
 
     return \@plugins;
@@ -434,7 +444,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =for Pod::Coverage .*
 
